@@ -8,13 +8,13 @@ class SassCompiler(object):
     supported_mimetypes = ['text/sass', 'text/scss']
 
     @classmethod
-    def compile(cls, what, mimetype='text/sass'):
+    def compile(cls, what, mimetype='text/sass', cwd=None):
         args = ['sass', '-s']
         if mimetype == 'text/scss':
             args.append('--scss')
 
         handler = subprocess.Popen(args, stdout=subprocess.PIPE, stdin=subprocess.PIPE,
-                                   stderr=subprocess.PIPE)
+                                   stderr=subprocess.PIPE, cwd=None)
 
         handler.stdin.write(what)
         handler.stdin.close()
